// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:wyatt_architecture/wyatt_architecture.dart';
import 'package:wyatt_i18n/src/core/enums/format.dart';

/// Base class for i18n data sources.
/// 
/// This class is used to load i18n files from a source.
/// It returns a [Future] that resolves to a [String] containing the i18n file
/// contents.
abstract class I18nDataSource extends BaseDataSource {
  const I18nDataSource({this.format = Format.arb});

  final Format format;

  /// Loads the i18n file from the source.
  /// If [locale] is not `null`, it will load the file with the given [locale].
  /// Otherwise, it will load the file from the default location.
  Future<String> load({required String? locale});

  /// Loads the i18n file from the source.
  /// 
  /// This method is used to load the i18n file from the given [Uri].
  Future<String> loadFrom(Uri uri);
}
