// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:wyatt_architecture/wyatt_architecture.dart';

/// Data structure for i18n files.
class I18n extends Entity {
  const I18n({
    required this.locale,
    required this.unparsedData,
    required this.data,
  }) : super();

  /// Creates an empty i18n file.
  const I18n.empty() : this(locale: '', unparsedData: '', data: const {});

  /// The locale of the i18n file.
  final String locale;

  /// The unparsed data of the i18n file.
  final String unparsedData;

  /// The data of the i18n file.
  final Map<String, dynamic> data;

  bool containsKey(String key) => data.containsKey(key);

  dynamic operator [](String key) => data[key];
}
