// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:wyatt_architecture/wyatt_architecture.dart';
import 'package:wyatt_i18n/src/core/utils/parser.dart';
import 'package:wyatt_i18n/src/domain/entities/i18n.dart';
import 'package:wyatt_type_utils/wyatt_type_utils.dart';

/// Base class for i18n repositories.
abstract class I18nRepository extends BaseRepository {
  const I18nRepository() : super();

  /// Loads the i18n file from the source.
  /// If [strict] is `true`, it will throw an NoLocaleException if the
  /// `@@locale` key is not found in the i18n file, otherwise it will
  /// set the locale to the given [locale].
  /// If [parser] is not `null`, it will use the given parser to parse
  /// the i18n file. Otherwise, it will use the default parser for the format.
  FutureOrResult<I18n> load({
    required String? locale,
    bool strict = false,
    Parser<String, Map<String, dynamic>>? parser,
  });

  /// Loads the i18n file from the given [uri].
  /// If [parser] is not `null`, it will use the given parser to parse
  /// the i18n file. Otherwise, it will use the default parser for the format.
  FutureOrResult<I18n> loadFrom(
    Uri uri, {
    Parser<String, Map<String, dynamic>>? parser,
  });

  /// Gets the translation for the given [key].
  Result<String, AppException> get(
    String key, [
    Map<String, dynamic> arguments = const {},
  ]);
}
